pub type SendRawTransactionOptions = BroadcastOptions;Expand description
Options for the sendrawtransaction RPC method.
Aliased Type
pub struct SendRawTransactionOptions {
pub max_fee_rate: Option<FeeRate>,
pub max_burn_amount: Option<Amount>,
}Fields
max_fee_rate: Option<FeeRate>Reject transactions whose fee rate is higher than this value.
Bitcoin Core expects this value as BTC/kvB.
max_burn_amount: Option<Amount>Reject transactions whose provably unspendable outputs exceed this amount.
Bitcoin Core expects this value as BTC.